@@ -1,6 +1,6 @@
 /********************************************
 init.c
-copyright 2008-2023,2024, Thomas E. Dickey
+copyright 2008-2024,2026, Thomas E. Dickey
 copyright 1991-1994,1995, Michael D. Brennan
 
 This is a source file for mawk, an implementation of
@@ -11,10 +11,16 @@ the GNU General Public License, version 2, 1991.
 ********************************************/
 
 /*
- * $MawkId: init.c,v 1.79 2024/08/18 20:29:34 tom Exp $
+ * $MawkId: init.c,v 1.88 2026/03/02 21:11:23 tom Exp $
  */
 
-/* init.c */
+#define Visible_ARRAY
+#define Visible_BI_REC
+#define Visible_CELL
+#define Visible_PFILE
+#define Visible_STRING
+#define Visible_SYMTAB
+
 #include <mawk.h>
 #include <code.h>
 #include <memory.h>
@@ -62,8 +68,8 @@ short interactive_flag = 0;
 #endif
 
 int dump_code_flag = 0;		/* if on dump internal code */
-short posix_space_flag = 0;
-short traditional_flag = 0;
+short posix_space_flag = 0;	/* -Wposix or --posix */
+short traditional_flag = 0;	/* -Wtraditional or --traditional */
 
 #ifndef NO_INTERVAL_EXPR
 #define enable_repetitions(flag) repetitions_flag = flag
@@ -102,7 +108,7 @@ static const struct {
 };
 /* *INDENT-ON* */
 
-static void
+static GCC_NORETURN void
 no_program(void)
 {
     mawk_exit(0);
@@ -164,7 +170,7 @@ ok_abbrev(const char *fullName, const char *partName, int partLen)
 	UChar ch = (UChar) partName[n];
 	if (isalpha(ch))
 	    ch = (UChar) toupper(ch);
-	if (ch != (UChar) toupper(fullName[n])) {
+	if (ch != (UChar) toupper((UChar) fullName[n])) {
 	    result = 0;
 	    break;
 	}
@@ -187,7 +193,7 @@ haveValue(char *value)
     int result = 0;
 
     if (*value++ == '=') {
-	if (*value != '\0' && strchr("=,", *value) == 0)
+	if (*value != '\0' && strchr("=,", *value) == NULL)
 	    result = 1;
     }
     return result;
@@ -376,7 +382,7 @@ handle_w_opt(W_OPTIONS code, int glue, char *option, char **value)
 	    mawk_exit(2);
 	}
 	wantArg = 1;
-	if (optNext != 0) {
+	if (optNext != NULL) {
 	    pfile_name = optNext;
 	    wantArg = 2;
 	} else {
@@ -396,7 +402,7 @@ handle_w_opt(W_OPTIONS code, int glue, char *option, char **value)
 
     case W_RANDOM:
 	wantArg = 1;
-	if (optNext != 0) {
+	if (optNext != NULL) {
 	    long x = numeric_option(optNext);
 	    CELL c[2];
 
@@ -417,12 +423,12 @@ handle_w_opt(W_OPTIONS code, int glue, char *option, char **value)
 
     case W_SPRINTF:
 	wantArg = 1;
-	if (optNext != 0) {
+	if (optNext != NULL) {
 	    long x = numeric_option(optNext);
 
 	    if (x > (long) sizeof(string_buff)) {
 		if (sprintf_buff != string_buff &&
-		    sprintf_buff != 0) {
+		    sprintf_buff != NULL) {
 		    zfree(sprintf_buff,
 			  (size_t) (sprintf_limit - sprintf_buff));
 		}
@@ -480,7 +486,7 @@ allow_long_options(char *arg, W_OPTIONS seen)
     char *env = getenv("MAWK_LONG_OPTIONS");
     int result = 0;
 
-    if (env != 0) {
+    if (env != NULL) {
 	switch (*env) {
 	default:
 	case 'e':		/* error */
@@ -675,6 +681,10 @@ process_cmdline(int argc, char **argv)
 
   no_more_opts:
 
+    if (!interactive_flag && isatty(fileno(stdout))) {
+	setbuf(stdout, (char *) 0);
+    }
+
     tail->link = (PFILE *) 0;
     pfile_list = dummy.link;
 
@@ -781,7 +791,7 @@ static ALL_ARRAYS *all_arrays;
 void
 array_leaks(void)
 {
-    while (all_arrays != 0) {
+    while (all_arrays != NULL) {
 	ALL_ARRAYS *next = all_arrays->next;
 	array_clear(all_arrays->a);
 	ZFREE(all_arrays->a);
